@@ -17,8 +17,7 @@
 #' It creates columns to indicate overlap information between two tables
 #'
 #' @param x Table with individuals in the cdm
-#' @param cdm Object that contains a cdm reference. Use CDMConnector to obtain a
-#' cdm reference.
+#' @param cdm A cdm_reference object.
 #' @param tableName name of the cohort that we want to check for overlap
 #' @param filterVariable the variable that we are going to use to filter (e.g.
 #' cohort_definition_id)
@@ -54,23 +53,26 @@
 #' }
 #'
 addIntersect <- function(x,
-                         cdm = attr(x, "cdm_reference"),
+                         cdm = lifecycle::deprecated(),
                          tableName,
                          value,
                          filterVariable = NULL,
                          filterId = NULL,
                          idName = NULL,
-                         window = list(c(0, Inf)), # list
+                         window = list(c(0, Inf)),
                          indexDate = "cohort_start_date",
                          censorDate = NULL,
-                         targetStartDate = getStartName(tableName),
-                         targetEndDate = getEndName(tableName),
+                         targetStartDate = startDateColumn(tableName),
+                         targetEndDate = endDateColumn(tableName),
                          order = "first",
                          nameStyle = "{value}_{id_name}_{window_name}") {
+  if (lifecycle::is_present(cdm)) {
+    lifecycle::deprecate_warn("0.6.0", "addIntersect(cdm)")
+  }
   if (!is.list(window)) {
     window <- list(window)
   }
-
+  cdm <- omopgenerics::cdmReference(x)
   # initial checks
   personVariable <- checkX(x)
   checkmate::assertCharacter(tableName, len = 1, any.missing = FALSE)
@@ -86,8 +88,6 @@ addIntersect <- function(x,
   checkNameStyle(nameStyle, filterTbl, windowTbl, value)
   checkVariableInX(censorDate, x, TRUE, "censorDate")
 
-  assertWriteSchema(cdm)
-
   if (!is.null(censorDate)) {
     checkCensorDate(x, censorDate)
   }
@@ -95,10 +95,12 @@ addIntersect <- function(x,
     idName <- checkSnakeCase(idName)
   }
 
-  tablePrefix <- c(sample(letters, 5, TRUE), "_") %>% paste0(collapse = "")
+  tablePrefix <- paste0(
+    "temp_",
+    c(sample(letters, 5, TRUE), "_") |> paste0(collapse = "")
+  )
 
   startTibble <- x
-  originalColnames <- colnames(x)
 
   # define overlapTable that contains the events of interest
   overlapTable <- cdm[[tableName]]
@@ -111,6 +113,28 @@ addIntersect <- function(x,
     overlapTable <- dplyr::mutate(overlapTable, "id" = 1)
   }
 
+  # columns that will be added
+  newCols <- expand.grid(
+    value = value,
+    id_name = filterTbl$id_name,
+    window_name = windowTbl$window_name
+  ) %>%
+    dplyr::as_tibble() %>%
+    dplyr::mutate(colnam = as.character(glue::glue(
+      nameStyle,
+      value = .data$value,
+      id_name = .data$id_name,
+      window_name = .data$window_name
+    ))) %>%
+    dplyr::select("colnam", "value") %>%
+    dplyr::mutate(colnam = checkSnakeCase(.data$colnam, verbose = F))
+  overwriteCols <- newCols$colnam[newCols$colnam %in% colnames(x)]
+  if (length(overwriteCols) > 0) {
+    cli::cli_warn("The following cols will be overwriten: {paste0(overwriteCols, collapse = ', ')}")
+    x <- x %>%
+      dplyr::select(-dplyr::all_of(overwriteCols))
+  }
+
   overlapTable <- overlapTable %>%
     dplyr::select(
       !!personVariable := dplyr::all_of(personVariableTable),
@@ -122,7 +146,6 @@ addIntersect <- function(x,
 
   result <- x %>%
     addFutureObservation(
-      cdm = cdm,
       indexDate = indexDate,
       futureObservationName = "days_to_add"
     ) %>%
@@ -139,9 +162,10 @@ addIntersect <- function(x,
     ) %>%
     dplyr::distinct() %>%
     dplyr::inner_join(overlapTable, by = personVariable) %>%
-    CDMConnector::computeQuery(
-      name = paste0(tablePrefix, "individuals"), temporary = FALSE,
-      schema = attr(cdm, "write_schema"), overwrite = TRUE
+    dplyr::compute(
+      name = paste0(tablePrefix, "individuals"),
+      temporary = FALSE,
+      overwrite = TRUE
     )
 
   resultCountFlag <- NULL
@@ -171,9 +195,10 @@ addIntersect <- function(x,
         )), 0, .data$indicator))
     }
     resultW <- resultW %>%
-      CDMConnector::computeQuery(
-        name = paste0(tablePrefix, "window"), temporary = FALSE,
-        schema = attr(cdm, "write_schema"), overwrite = TRUE
+      dplyr::compute(
+        name = paste0(tablePrefix, "window"),
+        temporary = FALSE,
+        overwrite = TRUE
       )
 
     # add count or flag
@@ -193,15 +218,18 @@ addIntersect <- function(x,
 
       if (i == 1) {
         resultCountFlag <- resultCF %>%
-          CDMConnector::computeQuery(
-            name = paste0(tablePrefix, "win_count_flag"), temporary = FALSE,
-            schema = attr(cdm, "write_schema"), overwrite = TRUE
+          dplyr::compute(
+            name = paste0(tablePrefix, "win_count_flag"),
+            temporary = FALSE,
+            overwrite = TRUE
           )
       } else {
-        resultCountFlag <- appendPermanent(
-            x = resultCF,
+        resultCountFlag <- resultCountFlag |>
+          dplyr::union_all(resultCF) |>
+          dplyr::compute(
             name = paste0(tablePrefix, "win_count_flag"),
-            schema = attr(cdm, "write_schema")
+            temporary = FALSE,
+            overwrite = TRUE
           )
       }
     }
@@ -271,16 +299,19 @@ addIntersect <- function(x,
 
       if (i == 1) {
         resultDateTimeOther <- resultDTO %>%
-          CDMConnector::computeQuery(
-            name = paste0(tablePrefix, "win_date_days"), temporary = FALSE,
-            schema = attr(cdm, "write_schema"), overwrite = TRUE
+          dplyr::compute(
+            name = paste0(tablePrefix, "win_date_days"),
+            temporary = FALSE,
+            overwrite = TRUE
           )
       } else {
-        resultDateTimeOther <- appendPermanent(
-          x = resultDTO,
-          name = paste0(tablePrefix, "win_date_days"),
-          schema = attr(cdm, "write_schema")
-        )
+        resultDateTimeOther <- resultDateTimeOther |>
+          dplyr::union_all(resultDTO) |>
+          dplyr::compute(
+            name = paste0(tablePrefix, "win_date_days"),
+            temporary = FALSE,
+            overwrite = TRUE
+          )
       }
     }
   }
@@ -301,32 +332,21 @@ addIntersect <- function(x,
     dplyr::rename(!!indexDate := "index_date") %>%
     dplyr::rename_all(tolower)
 
-    namesToEliminate <- intersect(colnames(x), colnames(resultCountFlagPivot))
-    namesToEliminate <- namesToEliminate[
-      !(namesToEliminate %in% c(personVariable, indexDate))
-    ]
-
+    newColCountFlag <- colnames(resultCountFlagPivot)
+    newColCountFlag <- newColCountFlag[newColCountFlag %in% newCols$colnam]
 
     x <- x %>%
-      dplyr::select(-dplyr::all_of(namesToEliminate)) %>%
       dplyr::left_join(
         resultCountFlagPivot,
         by = c(personVariable, indexDate)
       ) %>%
-      dplyr::mutate(dplyr::across(dplyr::all_of(namesToEliminate),
-                    ~ dplyr::if_else(is.na(.x), 0, .x)))
-
-    currentColnames <- colnames(x)
-
-    x <- x %>%
       dplyr::mutate(dplyr::across(
-        dplyr::all_of(currentColnames[!(currentColnames %in% originalColnames)]),
-        ~ dplyr::if_else(is.na(.x), 0, .x)
-      ))
-    x <- x %>%
-      CDMConnector::computeQuery(
-        name = paste0(tablePrefix, "count_flag"), temporary = FALSE,
-        schema = attr(cdm, "write_schema"), overwrite = TRUE
+        dplyr::all_of(newColCountFlag), ~ dplyr::if_else(is.na(.x), 0, .x)
+      )) %>%
+      dplyr::compute(
+        name = paste0(tablePrefix, "count_flag"),
+        temporary = FALSE,
+        overwrite = TRUE
       )
   }
 
@@ -335,8 +355,8 @@ addIntersect <- function(x,
     for (val in values) {
       resultDateTimeOtherX <- resultDateTimeOther %>%
         dplyr::select(
-          "subject_id", "index_date", dplyr::all_of(val), "id_name",
-          "window_name"
+          dplyr::all_of(personVariable), "index_date", dplyr::all_of(val),
+          "id_name", "window_name"
         ) %>%
         tidyr::pivot_longer(
           dplyr::all_of(val),
@@ -351,55 +371,54 @@ addIntersect <- function(x,
         dplyr::rename(!!indexDate := "index_date") %>%
         dplyr::rename_all(tolower)
 
-      namesToEliminate <- intersect(colnames(x), colnames(resultDateTimeOtherX))
-      namesToEliminate <- namesToEliminate[
-        !(namesToEliminate %in% c(personVariable, indexDate))
-      ]
-
       x <- x %>%
-        dplyr::select(-dplyr::all_of(namesToEliminate)) %>%
-        dplyr::left_join(resultDateTimeOtherX,
-          by = c(personVariable, indexDate)
+        dplyr::left_join(
+          resultDateTimeOtherX, by = c(personVariable, indexDate)
         )
     }
 
     x <- x %>%
-      CDMConnector::computeQuery(
-        name = paste0(tablePrefix, "date_days"), temporary = FALSE,
-        schema = attr(cdm, "write_schema"), overwrite = TRUE
+      dplyr::compute(
+        name = paste0(tablePrefix, "date_days"),
+        temporary = FALSE,
+        overwrite = TRUE
       )
 
   }
 
-  colnames <- expand.grid(value = value, id_name = filterTbl$id_name, window_name = windowTbl$window_name) %>%
-    dplyr::mutate(column = glue::glue(nameStyle, value = .data$value, id_name = .data$id_name, window_name = .data$window_name)) %>%
-    dplyr::mutate(val = ifelse(value %in% c("flag", "count"), 0,
-      ifelse(value %in% "date", as.Date(NA),
-        ifelse(value %in% "days", as.numeric(NA), as.character(NA))
-      )
-    )) %>%
-    dplyr::select(.data$column, .data$val) %>%
-    dplyr::mutate(column = checkSnakeCase(.data$column, verbose = F)) %>%
-    dplyr::anti_join(dplyr::tibble(column = colnames(x)), by = "column")
+  # missing columns
+  newCols <- newCols %>%
+    dplyr::filter(!.data$colnam %in% colnames(x))
 
-  if (colnames %>% dplyr::tally() %>% dplyr::pull() != 0) {
-    x <- x %>%
-      dplyr::cross_join(
-        colnames %>%
-          tidyr::pivot_wider(
-            names_from = .data$column,
-            values_from = .data$val
-          ),
-        copy = TRUE
+  for (val in as.character(unique(newCols$value))) {
+    cols <- newCols$colnam[newCols$value == val]
+    valk <- switch(
+      val,
+      flag = 0,
+      count = 0,
+      days = as.numeric(NA),
+      date = as.Date(NA),
+      as.character(NA)
+    )
+
+    id <- paste0("id_", paste0(sample(letters, 5), collapse = ""))
+
+    newTib <- dplyr::tibble(!!id := 1)
+    newTib[, cols] <- valk
+
+    x <- x |>
+      dplyr::mutate(!!id := 1) |>
+      dplyr::inner_join(newTib, copy = TRUE, by = id) |>
+      dplyr::compute(
+        name = paste0(tablePrefix, "_val"), temporary = FALSE, overwrite = TRUE
       )
   }
 
-  x <- CDMConnector::computeQuery(x)
+  x <- dplyr::compute(x)
 
-  CDMConnector::dropTable(cdm = cdm, name = dplyr::starts_with(tablePrefix))
-
-  # put back the initial attributes to the output tibble
-  x <- x %>% addAttributes(startTibble)
+  cdm <- omopgenerics::dropTable(
+    cdm = cdm, name = dplyr::starts_with(tablePrefix)
+  )
 
   return(x)
 }
@@ -415,10 +434,10 @@ addIntersect <- function(x,
 #' @examples
 #' \donttest{
 #' library(PatientProfiles)
-#' getStartName("condition_occurrence")
+#' startDateColumn("condition_occurrence")
 #' }
 #'
-getStartName <- function(tableName) {
+startDateColumn <- function(tableName) {
   if (tableName %in% namesTable$table_name) {
     return(namesTable$start_date_name[namesTable$table_name == tableName])
   } else {
@@ -437,10 +456,10 @@ getStartName <- function(tableName) {
 #' @examples
 #' \donttest{
 #' library(PatientProfiles)
-#' getEndName("condition_occurrence")
+#' endDateColumn("condition_occurrence")
 #' }
 #'
-getEndName <- function(tableName) {
+endDateColumn <- function(tableName) {
   if (tableName %in% namesTable$table_name) {
     return(namesTable$end_date_name[namesTable$table_name == tableName])
   } else {
@@ -448,7 +467,7 @@ getEndName <- function(tableName) {
   }
 }
 
-#' Get the name of the concept_id column for a certain table in the cdm
+#' Get the name of the standard concept_id column for a certain table in the cdm
 #'
 #' @param tableName Name of the table
 #'
@@ -459,10 +478,10 @@ getEndName <- function(tableName) {
 #' @examples
 #' \donttest{
 #' library(PatientProfiles)
-#' getConceptName("condition_occurrence")
+#' standardConceptIdColumn("condition_occurrence")
 #' }
 #'
-getConceptName <- function(tableName) {
+standardConceptIdColumn <- function(tableName) {
   if (tableName %in% namesTable$table_name) {
     return(namesTable$concept_id_name[namesTable$table_name == tableName])
   } else {
@@ -470,7 +489,7 @@ getConceptName <- function(tableName) {
   }
 }
 
-#' Get the name of the source_concept_id column for a certain table in the cdm
+#' Get the name of the source concept_id column for a certain table in the cdm
 #'
 #' @param tableName Name of the table
 #'
@@ -481,25 +500,13 @@ getConceptName <- function(tableName) {
 #' @examples
 #' \donttest{
 #' library(PatientProfiles)
-#' getSourceConceptName("condition_occurrence")
+#' sourceConceptIdColumn("condition_occurrence")
 #' }
 #'
-getSourceConceptName <- function(tableName) {
+sourceConceptIdColumn <- function(tableName) {
   if (tableName %in% namesTable$table_name) {
     return(namesTable$source_concept_id_name[namesTable$table_name == tableName])
   } else {
     return(as.character(NA))
   }
 }
-
-appendPermanent <- function(x, name, schema) {
-  con <- x$src$con
-  name <- CDMConnector::inSchema(
-    schema = schema, table = name, dbms = CDMConnector::dbms(con)
-  )
-  fullName <- DBI::dbQuoteIdentifier(con, name)
-  DBI::dbExecute(
-    con, glue::glue("INSERT INTO {fullName} {dbplyr::sql_render(x)}")
-  )
-  dplyr::tbl(con, name)
-}
